@@ -2,7 +2,12 @@ import pytest
 import six
 import sqlalchemy as sa
 
-from sqlalchemy_utils import PhoneNumber, PhoneNumberType, types  # noqa
+from sqlalchemy_utils import (  # noqa
+    PhoneNumber,
+    PhoneNumberParseException,
+    PhoneNumberType,
+    types
+)
 
 
 @pytest.fixture
@@ -77,6 +82,23 @@ class TestPhoneNumber(object):
             except:
                 pass
 
+    def test_invalid_phone_numbers_throw_dont_wrap_exception(
+        self,
+        session,
+        User
+    ):
+        try:
+            session.execute(
+                User.__table__.insert().values(
+                    name=u'Someone',
+                    phone_number=u'abc'
+                )
+            )
+        except PhoneNumberParseException:
+            pass
+        except:
+            assert False
+
     def test_phone_number_attributes(self):
         number = PhoneNumber('+358401234567')
         assert number.e164 == u'+358401234567'
